{% load wagtailadmin_tags compress static %}

{% comment %}
    Javascript declarations to be included on the 'create page' and 'edit page' views
{% endcomment %}

<script>
    window.chooserUrls = {
        'pageChooser': '{% url "wagtailadmin_choose_page" %}'
    };
</script>

{% compress js %}
    <script src="{% static 'wagtailadmin/js/vendor/rangy-core.js' %}"></script>
    <script src="{% static 'wagtailadmin/js/vendor/hallo.js' %}"></script>
    <script src="{% static 'wagtailadmin/js/vendor/tag-it.js' %}"></script>
    <script src="{% static 'wagtailadmin/js/expanding_formset.js' %}"></script>
    <script src="{% static 'wagtailadmin/js/modal-workflow.js' %}"></script>
    <script src="{% static 'wagtailadmin/js/hallo-plugins/hallo-wagtaillink.js' %}"></script>
    <script src="{% static 'wagtailadmin/js/hallo-plugins/hallo-hr.js' %}"></script>
    <script src="{% static 'wagtailadmin/js/hallo-plugins/hallo-requireparagraphs.js' %}"></script>
    <script src="{% static 'wagtailadmin/js/page-editor.js' %}"></script>
    <script src="{% static 'wagtailadmin/js/page-chooser.js' %}"></script>
    <script src="{% static 'admin/js/urlify.js' %}"></script>
    <script src="{% static 'wagtailadmin/js/privacy-switch.js' %}"></script>

    {% hook_output 'insert_editor_js' %}
{% endcompress %}

{% include "wagtailadmin/shared/datetimepicker_translations.html" %}

{% comment %}
    Additional js from widgets media. Allows for custom widgets in admin panel.
{% endcomment %}
{{ edit_handler.form.media.js }}

{% comment %}
    Additional HTML code that edit handlers define through 'html_declarations'. (Technically this isn't Javascript, but it will generally be data that exists for Javascript to work with...)
{% endcomment %}
{{ edit_handler.html_declarations }}
